# README

## files

______________________________________________________________________
|.gitignore		|a list of unshared files|
|makefile|dev tools for installing, publisizing etc.|
|pyproject.toml	|project metadata|
|requirements.txt |python dependencies|
|setup.py|necessary for `pip install -e .`|
|src/main.py|first file that gets called|
--------------------------------------------
